Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(148)

Unified Diff: views/window/window_win.cc

Issue 2862025: Canvas refactoring part 2.... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 10 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « views/widget/widget_win.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: views/window/window_win.cc
===================================================================
--- views/window/window_win.cc (revision 50452)
+++ views/window/window_win.cc (working copy)
@@ -13,7 +13,7 @@
#include "app/win_util.h"
#include "base/i18n/rtl.h"
#include "base/win_util.h"
-#include "gfx/canvas_paint.h"
+#include "gfx/canvas_skia_paint.h"
#include "gfx/font.h"
#include "gfx/icon_util.h"
#include "gfx/path.h"
@@ -938,13 +938,14 @@
root_view->SchedulePaint(gfx::Rect(dirty_region), false);
// gfx::CanvasPaints destructor does the actual painting. As such, wrap the
// following in a block to force paint to occur so that we can release the dc.
{
- gfx::CanvasPaint canvas(dc, opaque(), dirty_region.left, dirty_region.top,
- dirty_region.Width(), dirty_region.Height());
+ gfx::CanvasSkiaPaint canvas(dc, opaque(), dirty_region.left, dirty_region.top,
+ dirty_region.Width(), dirty_region.Height());
- root_view->ProcessPaint(&canvas);
+ root_view->ProcessPaint(canvas.AsCanvas());
}
ReleaseDC(GetNativeView(), dc);
« no previous file with comments | « views/widget/widget_win.cc ('k') | no next file » | no next file with comments »
@@ -938,13 +938,14 @@
root_view->SchedulePaint(gfx::Rect(dirty_region), false);
- // gfx::CanvasPaints destructor does the actual painting. As such, wrap the
- // following in a block to force paint to occur so that we can release the dc.
+ // gfx::CanvasSkiaPaint's destructor does the actual painting. As such, wrap
+ // the following in a block to force paint to occur so that we can release
+ // the dc.
{

Powered by Google App Engine
This is Rietveld 408576698